pub struct OpenedSensorBundle {
pub bundle: SensorBundle,
pub extracted_root: Option<PathBuf>,
}Expand description
Result of opening a sensor bundle from either a directory root or an archive file.
Fields
bundle: SensorBundleParsed sensor bundle.
extracted_root: Option<PathBuf>Temporary extraction root when opened from an archive path.
When this is Some, callers can remove the directory after use.