pub struct Sentinel1GeolocationGrid {
pub points: Vec<Sentinel1GeolocationGridPoint>,
}Expand description
Sentinel-1 geolocation grid parsed from an annotation XML.
The grid is sparsely sampled across image lines and pixels; all interpolation methods use bilinear interpolation over the irregular grid.
Fields
points: Vec<Sentinel1GeolocationGridPoint>Grid points sorted by (line, pixel).
Implementations
Sourceimpl Sentinel1GeolocationGrid
impl Sentinel1GeolocationGrid
Sourcepub fn interpolated_lat_lon(&self, row: usize, col: usize) -> Option<(f64, f64)>
pub fn interpolated_lat_lon(&self, row: usize, col: usize) -> Option<(f64, f64)>
Bilinearly interpolate (latitude, longitude) at the given image (row, col).
Sourcepub fn interpolated_height(&self, row: usize, col: usize) -> Option<f64>
pub fn interpolated_height(&self, row: usize, col: usize) -> Option<f64>
Bilinearly interpolate ellipsoidal height in metres at (row, col).